<?php
namespace App\Command;
use Illuminate\Http\Request;

class Log{
    //保留兼容以前日志
    static public function add(string $logKey, mixed $logInfo, ?Request $request = null) :void{
        try {
            // 判断当天的日志文件是否存在
            $day = date('Y-m-d');
            $logFileName = 'runLog_'.$day.'.log';
            $logPath = storage_path("logs/".$logFileName);
        
            // 检查日志目录是否存在，如果不存在则创建
            if (!is_dir(dirname($logPath))) {
                mkdir(dirname($logPath), 0777, true);
            }
        
            // 拼接用户信息
            if ($request && $request->user()) {
                $userObj = $request->user();
                $userInfo = "【-----------用户信息----------】".PHP_EOL;
                $userInfo .= "【用户ID】: ".$userObj->id.";".PHP_EOL; 
                $userInfo .= "【用户名称】: ".$userObj->name.";".PHP_EOL; 
                // 添加请求参数到日志信息
                $requestParams = $request->all();
                $paramInfo = "【请求参数】: ".print_r($requestParams, true).PHP_EOL;
                $userInfo .= $paramInfo;
            } else {
                $userInfo = "【-----------用户信息----------】".PHP_EOL;
                $userInfo .= "【未获取到用户信息】".PHP_EOL;
            }
        
            // 获取请求路径
            $requestPath = $request ? $request->getPathInfo() : 'N/A';
        
            // 添加请求路径到日志信息
            $logMessage = "--------------------".str_repeat("-", 20).PHP_EOL;
            $logMessage .= "【".date('Y-m-d H:i:s')."】".PHP_EOL."【返回值：】".$userInfo."【请求路径】: $requestPath 【".$logKey."】: ".print_r($logInfo, true).PHP_EOL;
            $logMessage .= "--------------------".str_repeat("-", 20).PHP_EOL.PHP_EOL;
        
            // 添加换行符
            file_put_contents($logPath, $logMessage, FILE_APPEND);
        } catch (\Exception $e) {
            // 记录异常信息到另一个日志文件
            $errorLogPath = storage_path("logs/error_log.log");
            file_put_contents($errorLogPath, "【".date('Y-m-d H:i:s')."】【add日志 方法出错】: ". $e->getMessage(). PHP_EOL, FILE_APPEND);
        }
    }


    
    // 中间件请求
    static public function RequestLog(string $logKey, mixed $logInfo, ?Request $request = null) :void{
        try {
            // 判断当天的日志文件是否存在
            $day = date('Y-m-d');
            $logFileName = 'runLog_Request'.$day.'.log';
            $logPath = storage_path("logs/".$logFileName);
        
            // 检查日志目录是否存在，如果不存在则创建
            if (!is_dir(dirname($logPath))) {
                mkdir(dirname($logPath), 0777, true);
            }
        
            // 拼接用户信息
            if ($request && $request->user()) {
                $userObj = $request->user();
                $userInfo = "【-----------用户信息----------】".PHP_EOL;
                $userInfo .= "【用户ID】: ".$userObj->id.";".PHP_EOL; 
                $userInfo .= "【用户名称】: ".$userObj->name.";".PHP_EOL; 
                // 添加请求参数到日志信息
                $requestParams = $request->all();
                $paramInfo = "【请求参数】: ".print_r($requestParams, true).PHP_EOL;
                $userInfo .= $paramInfo;
            } else {
                $userInfo = "【-----------用户信息----------】".PHP_EOL;
                $userInfo .= "【未获取到用户信息】".PHP_EOL;
            }
        
            // 获取请求路径
            $requestPath = $request ? $request->getPathInfo() : 'N/A';
        
            // 添加请求路径到日志信息
            $logMessage = "--------------------".str_repeat("-", 20).PHP_EOL;
            $logMessage .= "【".date('Y-m-d H:i:s')."】".PHP_EOL."【返回值：】".$userInfo."【请求路径】: $requestPath 【".$logKey."】: ".print_r($logInfo, true).PHP_EOL;
            $logMessage .= "--------------------".str_repeat("-", 20).PHP_EOL.PHP_EOL;
        
            // 添加换行符
            file_put_contents($logPath, $logMessage, FILE_APPEND);
        } catch (\Exception $e) {
            // 记录异常信息到另一个日志文件
            $errorLogPath = storage_path("logs/error_log.log");
            file_put_contents($errorLogPath, "【".date('Y-m-d H:i:s')."】【add日志 方法出错】: ". $e->getMessage(). PHP_EOL, FILE_APPEND);
        }
    }


    //自定义日志名字
    static public function addByName(string $logKey, mixed $logInfo, ?Request $request = null) :void{
        try {
            // 判断当天的日志文件是否存在
            $logFileName = 'runLog_'.$logKey.'.log';
            $logPath = storage_path("logs/".$logFileName);
        
            // 检查日志目录是否存在，如果不存在则创建
            if (!is_dir(dirname($logPath))) {
                mkdir(dirname($logPath), 0777, true);
            }
        
            // 拼接用户信息
            if ($request && $request->user()) {
                $userObj = $request->user();
                $userInfo = "【-----------用户信息----------】".PHP_EOL;
                $userInfo .= "【用户ID】: ".$userObj->id.";".PHP_EOL; 
                $userInfo .= "【用户名称】: ".$userObj->name.";".PHP_EOL; 
                // 添加请求参数到日志信息
                $requestParams = $request->all();
                $paramInfo = "【请求参数】: ".print_r($requestParams, true).PHP_EOL;
                $userInfo .= $paramInfo;
            } else {
                $userInfo = "【-----------用户信息----------】".PHP_EOL;
                $userInfo .= "【未获取到用户信息】".PHP_EOL;
            }
        
            // 获取请求路径
            $requestPath = $request ? $request->getPathInfo() : 'N/A';
        
            // 添加请求路径到日志信息
            $logMessage = "--------------------".str_repeat("-", 20).PHP_EOL;
            $logMessage .= "【".date('Y-m-d H:i:s')."】".PHP_EOL."【返回值：】".$userInfo."【请求路径】: $requestPath 【".$logKey."】: ".print_r($logInfo, true).PHP_EOL;
            $logMessage .= "--------------------".str_repeat("-", 20).PHP_EOL.PHP_EOL;
        
            // 添加换行符
            file_put_contents($logPath, $logMessage, FILE_APPEND);
        } catch (\Exception $e) {
            // 记录异常信息到另一个日志文件
            $errorLogPath = storage_path("logs/error_log.log");
            file_put_contents($errorLogPath, "【".date('Y-m-d H:i:s')."】【add日志 方法出错】: ". $e->getMessage(). PHP_EOL, FILE_APPEND);
        }
    }

}


