<?php

namespace App\Http\Controllers\Api;

use App\Command\Tools;
use App\Command\Log;
use App\Handlers\FileUploadHandler;
use App\Models\Merchant;
use App\Models\Store;
use App\Models\StoreAdminUsers;
use App\Models\UserPermission;
use App\Models\PersonalAccessToken;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class StoreAdminUsersController extends BaseController
{
    /**
     * 用户登录方法
     *
     * @param Request $request HTTP请求对象
     * @return \Illuminate\Http\JsonResponse JSON响应
     */
    public function login(Request $request)
    {
        $username = $request->username ?? '';
        $password = $request->password ?? '';

        $user = StoreAdminUsers::where(['username' => $username])->first();

        if (!$user) {
            return $this->JsonResponse('', '用户不存在', 201);
        }

        if (!Hash::check($password, $user->password)) {
            return $this->JsonResponse('', '账号或密码错误', 500);
        }

        // 生成token
        $accessToken = 'Bearer ' . $user->createToken('Access-token')->plainTextToken;

        // 记录登录日志
        Log::add('商家端用户--' . $user->id . '登录', ['token' => $accessToken]);

        return $this->JsonResponse([
            'Authorization' => $accessToken,
        ]);
    }

    /**
     * 用户注销方法
     *
     * @param Request $request HTTP请求对象
     * @return \Illuminate\Http\JsonResponse JSON响应
     */
    public function logout(Request $request)
    {
        $request->user()->tokens()->delete();
        PersonalAccessToken::where(['tokenable_id' => $request->user()->id])->delete();

        return $this->JsonResponse('');
    }

    /**
     * 获取用户信息方法
     *
     * @param Request $request HTTP请求对象
     * @return \Illuminate\Http\JsonResponse JSON响应
     */
    public function info(Request $request)
    {
        $muser = $request->user();
        $buycode = '';
        $merchant_id = $muser->merchant_id;
        $store_id = $muser->store_id;
        $total_revenue = $balance = $cashout = 0;
        $store_name = $merchant_name = '';

        if ($merchant_id) {
            $merObj = Merchant::where('id', $merchant_id)->first();
            $buycode = $merObj->buycode;
            $phone = $merObj->phone;
            $merchant_name = $merObj->name;
            $total_revenue = $merObj->total_revenue ?? 0;
            $balanceValue = $merObj->balance ?? 0;

            // 使用 Tools 类计算 T+1 未到账金额
            $pendingCashout = Tools::calculatePendingCashout($merchant_id);

            // 调整金额计算公式
            $displayBalance = $balanceValue + $pendingCashout;
            $displayCashout = $total_revenue - $displayBalance;

            $balance = number_format($displayBalance, 2, '.', '');
            $cashout = number_format($displayCashout, 2, '.', '');

            Log::add('balance金额', $balance);
            Log::add('cashout金额', $cashout);
        }

        if ($store_id) {
            $storeObj = Store::where('id', $store_id)->first();
            $store_name = $storeObj->title;
            $phone = $storeObj->phone;
        }

        return $this->JsonResponse([
            'user_id' => $muser->id,
            'username' => $muser->username,
            'merchant_name' => $merchant_name,
            'phone' => $phone,
            'openid' => $muser->openid ?? '',
            'avatar' => $muser->avatar ? env('IMAGE_URL') . $muser->avatar : env('NO_AVATAR_IMAGE_URL'),
            'merchant_id' => $muser->merchant_id,
            'buycode' => $buycode,
            'total_revenue' => $total_revenue,
            'balance' => $balance,
            'cashout' => $cashout,
            'role_id' => $muser->role_id,
            'store_name' => $store_name
        ]);
    }
}
